@@ -42,8 +42,10 @@ struct octt {
 };
 
 struct octt *octt_new();
-void octt_add(struct octt *ct,unsigned char r,unsigned char g,unsigned char b);
+int octt_add(struct octt *ct,unsigned char r,unsigned char g,unsigned char b);
 void octt_dump(struct octt *ct);
-void octt_count(struct octt *ct,int *tot);
+void octt_count(struct octt *ct,int *tot,int max,int *overflow);
+void octt_delete(struct octt *ct);
 
 #endif
+
